# Contribution

## Give ideas
You can use [issues](https://github.com/ylabonte/proconip-pypi/issues) 
to give ideas to and discuss with the community. At least I will try to read 
and respond to every issue (as fast as I can).

## Contribute code
The easiest way to contribute to this project would be to fork this repository, 
make your changes and then stage a pull request, if you think your changes could
be useful for the rest of the community.

## Gain maintainership
If you want to become a maintainer of this project, you can contact me. You will
not get write access to the `main` branch! This would require too much trust and
thus reduce the people in question too much. But with the first release version,
there will be a `develop` branch and if there is someone out there, who wants to 
help improve this adapter, I would suggest a git-flow workflow where we can review
each others changes using pull request.

## Contact
Feel free to contact me <yannic.labonte@gmail.com>, if you have any questions or 
concerns.
